@@ -12,11 +12,12 @@
 
 import {
   V1alpha2DevWorkspace,
-  V222Devfile,
-  V222DevfileComponents,
+  V230Devfile,
+  V230DevfileComponents,
 } from '@devfile/api';
 import { CoreV1EventList, V1PodList } from '@kubernetes/client-node';
 import * as webSocket from './webSocket';
+import { ReadStream } from 'fs';
 
 export { webSocket };
 
@@ -108,7 +109,7 @@ export interface IServerConfig {
   };
   defaults: {
     editor: string | undefined;
-    components: V222DevfileComponents[];
+    components: V230DevfileComponents[];
     plugins: IWorkspacesDefaultPlugins[];
     pvcStrategy: string | undefined;
   };
@@ -133,8 +134,6 @@ export interface IServerConfig {
   cheNamespace: string;
   pluginRegistryURL: string;
   pluginRegistryInternalURL: string;
-  devfileRegistryURL: string;
-  devfileRegistryInternalURL: string;
   dashboardLogo?: { base64data: string; mediatype: string };
 }
 
@@ -155,12 +154,16 @@ export interface IUserProfile {
   email: string;
   username: string;
 }
-export interface IDevWorkspacePreferences {
+export interface IWorkspacePreferences {
   'skip-authorisation': GitProvider[];
-  [key: string]: string | string[];
+  'trusted-sources'?: TrustedSources;
+  [key: string]: unknown;
 }
+export type TrustedSourceAll = '*';
+export type TrustedSourceUrl = string;
+export type TrustedSources = TrustedSourceAll | TrustedSourceUrl[];
 
-export type IEditors = Array<V222Devfile>;
+export type IEditors = Array<V230Devfile>;
 
 export type IEventList = CoreV1EventList;
 export type IPodList = V1PodList;
@@ -189,3 +192,14 @@ export interface IGettingStartedSample {
   url: string;
   tags?: Array<string>;
 }
+
+export interface IAirGapSample extends IGettingStartedSample {
+  id: string;
+  project?: { zip?: { filename?: string } };
+  devfile?: { filename?: string };
+}
+
+export interface IStreamedFile {
+  stream: ReadStream;
+  size: number;
+}
