@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -40,8 +40,8 @@ export function registerKubeConfigRoute(instance: FastifyInstance) {
         const { kubeConfigApi } = getDevWorkspaceClient(token);
         const { namespace, devworkspaceId } = request.params as restParams.INamespacedPodParams;
         await kubeConfigApi.injectKubeConfig(namespace, devworkspaceId);
-        reply.code(204);
-        return reply.send();
+
+        reply.code(204).send();
       },
     );
   });
