@@ -23,6 +23,7 @@ import {
   getRestartInDebugModeLocation,
   getRestartInSafeModeLocation,
 } from '@/components/WorkspaceProgress/StartingSteps/StartWorkspace/prepareRestart';
+import { ToggleBarsContext } from '@/contexts/ToggleBars';
 import styles from '@/pages/Loader/index.module.css';
 import { DevWorkspaceStatus, LoaderTab } from '@/services/helpers/types';
 import { Workspace } from '@/services/workspace-adapter';
@@ -40,6 +41,9 @@ export type State = {
 };
 
 export class LoaderPage extends React.PureComponent<Props, State> {
+  static contextType = ToggleBarsContext;
+  readonly context: React.ContextType<typeof ToggleBarsContext>;
+
   private readonly appliedSafeMode: { [key: string]: boolean };
 
   constructor(props: Props) {
@@ -55,6 +59,11 @@ export class LoaderPage extends React.PureComponent<Props, State> {
     this.appliedSafeMode = {};
   }
 
+  componentDidMount(): void {
+    // hide top and side bars
+    this.context.hideAll();
+  }
+
   private handleTabClick(tabIndex: React.ReactText): void {
     const tabKey = tabIndex as LoaderTab;
 
@@ -82,6 +91,9 @@ export class LoaderPage extends React.PureComponent<Props, State> {
     }
     const showToastAlert = activeTabKey !== LoaderTab.Progress;
 
+    const isLogsTabDisabled = workspace === undefined;
+    const isEventsTabDisabled = workspace === undefined;
+
     return (
       <React.Fragment>
         <Head pageName={pageTitle} />
@@ -117,6 +129,8 @@ export class LoaderPage extends React.PureComponent<Props, State> {
               title={LoaderTab.Logs}
               data-testid="loader-logs-tab"
               id="loader-logs-tab"
+              isDisabled={isLogsTabDisabled}
+              isAriaDisabled={isLogsTabDisabled}
             >
               <WorkspaceLogs workspaceUID={workspace?.uid} />
             </Tab>
@@ -125,6 +139,8 @@ export class LoaderPage extends React.PureComponent<Props, State> {
               title={LoaderTab.Events}
               data-testid="loader-events-tab"
               id="loader-events-tab"
+              isDisabled={isEventsTabDisabled}
+              isAriaDisabled={isEventsTabDisabled}
             >
               <WorkspaceEvents workspaceUID={workspace?.uid} />
             </Tab>
