@@ -132,6 +132,6 @@ describe('Delete Registries Modal', () => {
     const cancelButton = screen.getByTestId('cancel-button');
     userEvent.click(cancelButton);
 
-    expect(mockOnCancel).toBeCalled();
+    expect(mockOnCancel).toHaveBeenCalled();
   });
 });
