@@ -54,7 +54,7 @@ describe('AddModal', () => {
     expect(closeButton).toBeTruthy();
 
     userEvent.click(closeButton!);
-    expect(mockOnClose).toBeCalledTimes(1);
+    expect(mockOnClose).toHaveBeenCalledTimes(1);
   });
 
   it('should handle click on Cancel button', () => {
@@ -64,7 +64,7 @@ describe('AddModal', () => {
     expect(cancelButton).toBeTruthy();
 
     userEvent.click(cancelButton!);
-    expect(mockOnClose).toBeCalledTimes(1);
+    expect(mockOnClose).toHaveBeenCalledTimes(1);
   });
 
   describe('modal window', () => {
@@ -117,7 +117,7 @@ describe('AddModal', () => {
       userEvent.click(addButton);
 
       // expect onSave to be called
-      expect(mockOnSave).toBeCalledTimes(1);
+      expect(mockOnSave).toHaveBeenCalledTimes(1);
     });
 
     it('should handle invalid SSH key', () => {
