@@ -25,29 +25,63 @@ import {
 } from '@/services/workspace-client/helpers';
 import { FakeStoreBuilder } from '@/store/__mocks__/storeBuilder';
 
+// mute console.error
+console.error = jest.fn();
+
 describe('Workspace-client helpers', () => {
   describe('get an error message', () => {
     it('should return the default error message', () => {
       expect(getErrorMessage(undefined)).toEqual('Check the browser logs message.');
     });
+
     it('should return the unknown error message', () => {
       expect(getErrorMessage({})).toEqual('Unexpected error type. Please report a bug.');
     });
+
     it('should return the error message', () => {
+      const message = getErrorMessage({
+        response: {
+          status: 500,
+          statusText: 'Internal Server Error',
+          headers: {},
+          config: {},
+          data: 'Some error message',
+        },
+        request: {
+          responseURL: 'http://dummyurl.com',
+        },
+      });
+      expect(message).toEqual('Some error message');
+    });
+
+    it('should return the error details', () => {
       expect(
         getErrorMessage({
           response: {
-            status: 401,
+            status: 500,
           },
           request: {
             responseURL: 'http://dummyurl.com',
           },
         }),
       ).toEqual(
-        'HTTP Error code 401. Endpoint which throws an error http://dummyurl.com. Check the browser logs message.',
+        'HTTP Error code 500. Endpoint which throws an error http://dummyurl.com. Check the browser logs message.',
       );
     });
+
+    it('should report the Unauthorized (or Forbidden) error', () => {
+      const message = getErrorMessage({
+        response: {
+          status: 401,
+          request: {
+            responseURL: 'http://dummyurl.com',
+          },
+        },
+      });
+      expect(message).toContain('User session has expired. You need to re-login to the Dashboard.');
+    });
   });
+
   describe('checks for HTML login page in response data', () => {
     it('should return false without  HTML login page', () => {
       expect(
@@ -62,6 +96,7 @@ describe('Workspace-client helpers', () => {
         }),
       ).toBeFalsy();
     });
+
     it('should return true in the case with  HTML login page', () => {
       expect(
         hasLoginPage({
@@ -76,6 +111,7 @@ describe('Workspace-client helpers', () => {
       ).toBeTruthy();
     });
   });
+
   describe('checks for HTTP 401 Unauthorized response status code', () => {
     it('should return false in the case with HTTP 400 Bad Request', () => {
       expect(isUnauthorized('...HTTP Status 400 ....')).toBeFalsy();
@@ -101,6 +137,7 @@ describe('Workspace-client helpers', () => {
         }),
       ).toBeFalsy();
     });
+
     it('should return true in the case with HTTP 401 Unauthorized', () => {
       expect(isUnauthorized('...HTTP Status 401 ....')).toBeTruthy();
       expect(
@@ -126,6 +163,7 @@ describe('Workspace-client helpers', () => {
       ).toBeTruthy();
     });
   });
+
   describe('checks for HTTP 403 Forbidden response status code', () => {
     it('should return false in the case with HTTP 400 Bad Request', () => {
       expect(isForbidden('...HTTP Status 400 ....')).toBeFalsy();
@@ -151,6 +189,7 @@ describe('Workspace-client helpers', () => {
         }),
       ).toBeFalsy();
     });
+
     it('should return true in the case with HTTP 403 Forbidden', () => {
       expect(isForbidden('...HTTP Status 403 ....')).toBeTruthy();
       expect(
@@ -176,6 +215,7 @@ describe('Workspace-client helpers', () => {
       ).toBeTruthy();
     });
   });
+
   describe('checks for HTTP 500 Internal Server Error response status code', () => {
     it('should return false in the case with HTTP 400 Bad Request', () => {
       expect(isInternalServerError('...HTTP Status 400 ....')).toBeFalsy();
@@ -201,6 +241,7 @@ describe('Workspace-client helpers', () => {
         }),
       ).toBeFalsy();
     });
+
     it('should return true in the case with HTTP 500 Internal Server Error', () => {
       expect(isInternalServerError('...HTTP Status 500 ....')).toBeTruthy();
       expect(
@@ -323,15 +364,32 @@ describe('Workspace-client helpers', () => {
           optionalFilesContent[CHE_EDITOR_YAML_PATH] = dump({
             id: 'che-incubator/che-idea/next',
           });
-          const store = new FakeStoreBuilder()
-            .withDevfileRegistries({
-              devfiles: {
-                ['https://dummy-plugin-registry/plugins/che-incubator/che-idea/next/devfile.yaml']:
-                  {
-                    content: dump(editor),
-                  },
+
+          const editors = [
+            {
+              schemaVersion: '2.1.0',
+              metadata: {
+                name: 'che-idea',
+                namespace: 'che',
+                attributes: {
+                  publisher: 'che-incubator',
+                  version: 'next',
+                },
               },
-            })
+              components: [
+                {
+                  name: 'eclipse-ide',
+                  container: {
+                    image: 'docker.io/wsskeleton/eclipse-broadway',
+                    mountSources: true,
+                    memoryLimit: '2048M',
+                  },
+                },
+              ],
+            } as devfileApi.Devfile,
+          ];
+          const store = new FakeStoreBuilder()
+            .withDwPlugins({}, {}, false, editors, 'che-incubator/che-idea/next')
             .build();
 
           const customEditor = await getCustomEditor(
@@ -356,6 +414,31 @@ describe('Workspace-client helpers', () => {
               ],
             },
           });
+
+          const editors = [
+            {
+              schemaVersion: '2.1.0',
+              metadata: {
+                name: 'che-idea',
+                namespace: 'che',
+                attributes: {
+                  publisher: 'che-incubator',
+                  version: 'next',
+                },
+              },
+              components: [
+                {
+                  name: 'eclipse-ide',
+                  container: {
+                    image: 'docker.io/wsskeleton/eclipse-broadway',
+                    mountSources: true,
+                    memoryLimit: '2048M',
+                  },
+                },
+              ],
+            } as devfileApi.Devfile,
+          ];
+
           const store = new FakeStoreBuilder()
             .withDevfileRegistries({
               devfiles: {
@@ -365,6 +448,7 @@ describe('Workspace-client helpers', () => {
                   },
               },
             })
+            .withDwPlugins({}, {}, false, editors, 'che-incubator/che-idea/next')
             .build();
 
           const customEditor = await getCustomEditor(
@@ -377,12 +461,36 @@ describe('Workspace-client helpers', () => {
           expect(customEditor).toEqual(expect.stringContaining('memoryLimit: 1234Mi'));
         });
 
-        it('should throw the "missing metadata.name" error message', async () => {
+        it('should failed fetching editor without metadata.name attribute', async () => {
           // set an empty value as a name
           editor.metadata.name = '';
           optionalFilesContent[CHE_EDITOR_YAML_PATH] = dump({
             id: 'che-incubator/che-idea/next',
           });
+
+          const editors = [
+            {
+              schemaVersion: '2.1.0',
+              metadata: {
+                namespace: 'che',
+                attributes: {
+                  publisher: 'che-incubator',
+                  version: 'next',
+                },
+              },
+              components: [
+                {
+                  name: 'eclipse-ide',
+                  container: {
+                    image: 'docker.io/wsskeleton/eclipse-broadway',
+                    mountSources: true,
+                    memoryLimit: '2048M',
+                  },
+                },
+              ],
+            } as devfileApi.Devfile,
+          ];
+
           const store = new FakeStoreBuilder()
             .withDevfileRegistries({
               devfiles: {
@@ -392,6 +500,7 @@ describe('Workspace-client helpers', () => {
                   },
               },
             })
+            .withDwPlugins({}, {}, false, editors, 'che-incubator/che-idea/next')
             .build();
 
           let errorText: string | undefined;
@@ -407,10 +516,11 @@ describe('Workspace-client helpers', () => {
           }
 
           expect(errorText).toEqual(
-            'Failed to analyze the editor devfile, reason: Missing metadata.name attribute in the editor yaml file.',
+            'Failed to fetch editor yaml by id: che-incubator/che-idea/next.',
           );
         });
       });
+
       describe('from the custom registry', () => {
         it('should return an editor without changes', async () => {
           optionalFilesContent[CHE_EDITOR_YAML_PATH] = dump({
@@ -515,8 +625,12 @@ function buildEditor(): devfileApi.Devfile {
   return {
     schemaVersion: '2.1.0',
     metadata: {
-      name: 'ws-skeleton/eclipseide/4.9.0',
+      name: 'che-idea',
       namespace: 'che',
+      attributes: {
+        publisher: 'che-incubator',
+        version: 'next',
+      },
     },
     components: [
       {
