@@ -14,13 +14,13 @@ import common from '@eclipse-che/common';
 import { load } from 'js-yaml';
 import { Action, Reducer } from 'redux';
 
+import { fetchEditors } from '@/services/backend-client/editorsApi';
 import devfileApi from '@/services/devfileApi';
 import { fetchDevfile } from '@/services/registry/devfiles';
 import { fetchData } from '@/services/registry/fetchData';
 import { AppThunk } from '@/store';
 import { createObject } from '@/store/helpers';
 import { AUTHORIZED, SanityCheckAction } from '@/store/sanityCheckMiddleware';
-import { selectPluginRegistryUrl } from '@/store/ServerConfig/selectors';
 
 export interface PluginDefinition {
   plugin?: devfileApi.Devfile;
@@ -43,6 +43,21 @@ export interface State {
   defaultPlugins: WorkspacesDefaultPlugins;
   defaultEditorName?: string;
   defaultEditorError?: string;
+  cmEditors?: devfileApi.Devfile[];
+}
+
+export interface RequestEditorsAction extends Action {
+  type: 'REQUEST_EDITORS';
+}
+
+export interface ReceiveEditorsAction extends Action {
+  type: 'RECEIVE_EDITORS';
+  editors: devfileApi.Devfile[];
+}
+
+export interface ReceiveEditorsErrorAction {
+  type: 'RECEIVE_EDITORS_ERROR';
+  error: string;
 }
 
 export interface RequestDwDefaultEditorAction extends Action, SanityCheckAction {
@@ -115,11 +130,15 @@ export type KnownAction =
   | ReceiveDwDefaultEditorErrorAction
   | RequestDwEditorAction
   | ReceiveDwEditorAction
+  | RequestEditorsAction
+  | ReceiveEditorsAction
+  | ReceiveEditorsErrorAction
   | RequestDwEditorErrorAction
   | RequestDwDefaultPluginsAction
   | ReceiveDwDefaultPluginsAction;
 
 export type ActionCreators = {
+  requestEditors: () => AppThunk<KnownAction, Promise<void>>;
   requestDwDevfile: (url: string) => AppThunk<KnownAction, Promise<void>>;
   requestDwDefaultEditor: () => AppThunk<KnownAction, Promise<void>>;
   requestDwDefaultPlugins: () => AppThunk<KnownAction, Promise<void>>;
@@ -154,54 +173,103 @@ export const actionCreators: ActionCreators = {
       }
     },
 
+  requestEditors:
+    (): AppThunk<KnownAction, Promise<void>> =>
+    async (dispatch): Promise<void> => {
+      dispatch({
+        type: 'REQUEST_EDITORS',
+      });
+
+      try {
+        const editors = (await fetchEditors()) as devfileApi.Devfile[];
+        const filteredEditors: devfileApi.Devfile[] = [];
+        editors.forEach(editor => {
+          if (
+            !editor.metadata.attributes.publisher ||
+            !editor.metadata.attributes.version ||
+            !editor.metadata.name
+          ) {
+            console.error(
+              `Missing metadata attributes in the editor yaml file: ${editor.metadata.name}. metadata.name, metadata.attributes.publisher and metadata.attributes.version should be set. Skipping this editor.`,
+            );
+          } else {
+            filteredEditors.push(editor);
+          }
+        });
+        dispatch({
+          type: 'RECEIVE_EDITORS',
+          editors: filteredEditors,
+        });
+      } catch (e) {
+        const errorMessage = common.helpers.errors.getMessage(e);
+        dispatch({
+          type: 'RECEIVE_EDITORS_ERROR',
+          error: errorMessage,
+        });
+        throw errorMessage;
+      }
+    },
+
   requestDwEditor:
     (editorName: string): AppThunk<KnownAction, Promise<void>> =>
     async (dispatch, getState): Promise<void> => {
       let editorUrl: string;
-      // check if the editor is an id or a path to a given editor
+      // check if the editor is an id or URL to a given editor
       if (editorName.startsWith('https://')) {
         editorUrl = editorName;
-      } else {
-        const pluginRegistryUrl = selectPluginRegistryUrl(getState());
-        editorUrl = `${pluginRegistryUrl}/plugins/${editorName}/devfile.yaml`;
-
-        if (!pluginRegistryUrl) {
-          const errorMessage =
-            'Failed to load the default editor, reason: plugin registry URL is not provided by Che server.';
+        try {
+          dispatch({
+            type: 'REQUEST_DW_EDITOR',
+            check: AUTHORIZED,
+            url: editorUrl,
+            editorName,
+          });
+          const pluginContent = await fetchData<string>(editorUrl);
+          const plugin = load(pluginContent) as devfileApi.Devfile;
+          dispatch({
+            type: 'RECEIVE_DW_EDITOR',
+            editorName,
+            url: editorUrl,
+            plugin,
+          });
+        } catch (error) {
+          const errorMessage = `Failed to load the editor ${editorName}. Invalid devfile. Check 'che-editor' param.`;
           dispatch({
             type: 'RECEIVE_DW_EDITOR_ERROR',
             url: editorUrl,
             editorName,
             error: errorMessage,
           });
+          throw common.helpers.errors.getMessage(error);
+        }
+      } else {
+        const editors = getState().dwPlugins.cmEditors || [];
+        const editor = editors.find(
+          editor =>
+            editor.metadata.attributes.publisher +
+              '/' +
+              editor.metadata.name +
+              '/' +
+              editor.metadata.attributes.version ===
+            editorName,
+        );
+        if (!editor) {
+          const errorMessage = `Failed to load editor ${editorName}. The editor does not exist in the editors configuration map.`;
+          dispatch({
+            type: 'RECEIVE_DW_EDITOR_ERROR',
+            url: '',
+            editorName,
+            error: errorMessage,
+          });
           throw errorMessage;
+        } else {
+          dispatch({
+            type: 'RECEIVE_DW_EDITOR',
+            editorName,
+            url: '',
+            plugin: editor,
+          });
         }
-      }
-
-      try {
-        dispatch({
-          type: 'REQUEST_DW_EDITOR',
-          check: AUTHORIZED,
-          url: editorUrl,
-          editorName,
-        });
-        const pluginContent = await fetchData<string>(editorUrl);
-        const plugin = load(pluginContent) as devfileApi.Devfile;
-        dispatch({
-          type: 'RECEIVE_DW_EDITOR',
-          editorName,
-          url: editorUrl,
-          plugin,
-        });
-      } catch (error) {
-        const errorMessage = `Failed to load the editor ${editorName}. Invalid devfile. Check 'che-editor' param.`;
-        dispatch({
-          type: 'RECEIVE_DW_EDITOR_ERROR',
-          url: editorUrl,
-          editorName,
-          error: errorMessage,
-        });
-        throw common.helpers.errors.getMessage(error);
       }
     },
 
@@ -225,10 +293,9 @@ export const actionCreators: ActionCreators = {
         throw errorMessage;
       }
 
-      const pluginRegistryURL = selectPluginRegistryUrl(getState());
       const defaultEditorUrl = (defaultEditor as string).startsWith('https://')
         ? defaultEditor
-        : `${pluginRegistryURL}/plugins/${defaultEditor}/devfile.yaml`;
+        : '';
 
       // request default editor
       await dispatch(actionCreators.requestDwEditor(defaultEditor));
@@ -270,6 +337,7 @@ const unloadedState: State = {
   editors: {},
   defaultPlugins: {},
   defaultEditorName: undefined,
+  cmEditors: [],
 };
 
 export const reducer: Reducer<State> = (
@@ -282,6 +350,20 @@ export const reducer: Reducer<State> = (
 
   const action = incomingAction as KnownAction;
   switch (action.type) {
+    case 'REQUEST_EDITORS':
+      return createObject<State>(state, {
+        isLoading: true,
+      });
+    case 'RECEIVE_EDITORS':
+      return createObject<State>(state, {
+        isLoading: false,
+        cmEditors: action.editors,
+      });
+    case 'RECEIVE_EDITORS_ERROR':
+      return createObject<State>(state, {
+        isLoading: false,
+        cmEditors: [],
+      });
     case 'REQUEST_DW_PLUGIN':
       return createObject<State>(state, {
         isLoading: true,
